---
name: Feature request
about: Suggest an new feature in ctapipe
title: ''
labels: enhancement
assignees: ''

---

**Please describe the use case that requires this feature.**
A clear and concise description of why this feature is needed. [...]

**Describe the solution you'd like**
A clear and concise description of what you want to happen.

**Describe alternatives you've considered**
A clear and concise description of any alternative solutions or features you've considered.

**Additional context**
Add any other context or screenshots about the feature request here.
